########## Data Visualization and Analysis for Benthic Data
########## Bocas 2017 zoanthid x OA experiment with Porites spp.:Benthic Data
## Author: MD Johnson
## Updated: 12/28/2021

##MS Authors: Violet Doucette, Lucia Rodriguez, Andrew Altieri, Maggie D. Johnson

##MS Title: Negative  effects of a zoanthid competitor limit coral calcification more than ocean acidification 

## Getting started
#Set WD and load all libraries and data files

setwd("/Users/magjo/Desktop/Projects 2020/Coral x zoanthid/Responses 2021 Analysis/")

rm(list=ls())

#Load necessary libraries
library(ggplot2) # graphing
library(tidyverse)
library(dplyr)

#Load data files as csv
rawall <- read.csv(file="allbenthic.csv")
rawzc <- read.csv(file="zoandcoralpercent.csv")

## Set up for graphing
#Make custom theme for all plots
mytheme <- theme_classic() + theme(text = element_text(size=11))+
  theme(axis.text.x = element_text(size=10,colour="black"), axis.text.y =     
          element_text(size=10,colour="black"))+
  theme(plot.margin = unit(c(5.5,5.5,5.5,20), "pt"))+
  theme(panel.border = element_rect(colour = "black", fill=NA, size=0.5))+
  theme(axis.line = element_line(size = 0))


### Set color palette 
plot.col2<-c("lightseagreen","deepskyblue4","cyan","aquamarine3","cadetblue2","beige","darksalmon","chocolate1","darkgoldenrod1")   


################################################
################################################
#### Stacked bar plot of all benthic data

## prep dataframe and check that data loaded
all <- rawall
head(all)

### Convert from wide format to long format with a Functional group column 
all_long <- gather(all, Group, Cover, LiveCoral:Other, factor_key=TRUE)
head(all_long)

#Rename columns
colnames(all_long)<-c("Site","Plot","Group","Cover")
head(all_long)

### Calculate the mean, sd, se of each functional group by site
funct.mean<- all_long %>% 
  group_by(Site, Group) %>%  
  summarize(N = sum(!is.na(Cover)),
            CoverMean = mean(Cover,na.rm=T),
            SD = sd(Cover,na.rm=T),
            SE =SD/sqrt(N))
 
total.mean<-funct.mean %>% group_by(Group) %>% 
  summarise(N    = sum(!is.na(CoverMean)),
                   Cover = mean(CoverMean, na.rm=TRUE),
                   Coversd = sd(CoverMean),
                   Coverse = (sd(CoverMean)/sqrt(N)))

#Check the means
head(funct.mean)

# You can use this to change the order of your Sites
funct.mean$Site <- factor(funct.mean$Site, levels=c("Almirante","Caracol", "IslandPoint", "Pastores", "PuntaJuan"))

FigS1 <- 
  ggplot(funct.mean, aes(fill=Group, y=CoverMean, x=Site))+
  geom_bar(position="stack", stat="identity", width=0.7,color="black")+
  labs(y='Percent Cover')+ 
  scale_fill_manual(values=plot.col2,
  labels = c("Live Coral", "Dead Coral", "Other Inverts", "Sponges", "Zoanthids", "Substrate","Algae", "Other"))+
    mytheme

FigS1                   

### Visualize percent of inverts zoanthid and percent coral porites
head(rawzc)

### Convert from wide format to long format with a Functional group column 
zc_long <- gather(rawzc, Group, Cover, PercZonocoral:PercCoralPor, factor_key=TRUE)
head(zc_long)

### Calculate the mean, sd, se of each functional group by site
sp.mean<- zc_long %>% 
  group_by(Site, Group) %>%  
  summarize(N = sum(!is.na(Cover)),
            CoverMean = mean(Cover,na.rm=T),
            SD = sd(Cover,na.rm=T),
            SE =SD/sqrt(N))

total.sp<-sp.mean %>% group_by(Group) %>% 
  summarise(N    = sum(!is.na(CoverMean)),
            Cover = mean(CoverMean, na.rm=TRUE),
            Coversd = sd(CoverMean),
            Coverse = (sd(CoverMean)/sqrt(N)))
total.sp

#Check the means
head(sp.mean)

zoanthid <- sp.mean %>% filter(Group =="PercZonocoral")
coral <- sp.mean %>% filter (Group == "PercCoralPor")


Fig1c <- ggplot(coral, aes(x=Site, y=CoverMean, fill=Group))+ 
  geom_bar(stat="identity", position=position_dodge(), alpha=0.9, color = "black")+ 
  geom_errorbar (aes(x=Site, ymin=CoverMean-SE, ymax=CoverMean+SE), width=0, size=.5, position=position_dodge(.9))+
  labs(x="Site", y="Percent Cover")+ 
  scale_fill_manual(values=c("lightseagreen"),labels = c("Porites spp."))+
  mytheme
Fig1c

Fig1d <- ggplot(zoanthid, aes(x=Site, y=CoverMean, fill=Group))+ 
  geom_bar(stat="identity", position=position_dodge(), alpha=0.9, color = "black")+ 
  geom_errorbar (aes(x=Site, ymin=CoverMean-SE, ymax=CoverMean+SE), width=0, size=.5, position=position_dodge(.9))+
  labs(x="Site", y="Percent Cover")+ 
  scale_fill_manual(values=c("cadetblue2"),labels = c("Z.pulchellus"))+
  mytheme
Fig1d

